@@ -1,8 +1,9 @@
 % use 5.010;
-% use Tapper::Reports::DPath 'reportdata';
+% use Tapper::Reports::DPath 'reportdata', 'testrundata', 'testplandata';
 % use Data::Dumper;
 % use Data::DPath 'dpath';
 % use DateTime;
 % use JSON;
 % use YAML::XS;
 % use Data::Structure::Util 'unbless';
+% $Data::Dumper::Sortkeys = 1;
